<?php
    /**
     * Plugin Name: Story Show Gallery
     * Plugin URI: https://ssg.flor.cz/wordpress/
     * Description: Responsive image gallery. It nicely combines images and captions to show a whole story in full screen, non-distracting environment.
     * Version: 1.3.4
     * Author: Roman Flössler
     * Author URI: https://ssg.flor.cz/
     * License: GPL-2.0+
     * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
     */

    defined( 'ABSPATH' ) or die( 'Only for Wordpress' );
    
    /* Adding Submenu under Settings Tab */
        
    function ssg_add_menu() {
        add_submenu_page ( 'options-general.php', 'Story Show Gallery', 'Story Show Gallery', 'manage_options', 'story-show-gallery', 'ssg_admin_page_render' );
    }
    add_action ( 'admin_menu', 'ssg_add_menu' );

    
    /* Settings page - HTML and form   */

    function ssg_admin_page_render() {
        $ssg_url = plugin_dir_url( __FILE__ );
?>

        <div class="wrap">
            <h1>
                Story Show Gallery
            </h1><br />
            <p class="text green">&#10003; Story Show Gallery is now active. Photos from galleries are now opening into SSG. 
            </p>
            <p class="text crucial">
                Story Show Gallery use Wordpress standard gallery for generating thumbnails, so dealing with images stays the same.
                <br /> <strong class="important">Important!</strong> If you use new Gutenberg gallery, 
                SSG will open only if you set this gallery's option: <img src="<?php echo $ssg_url; ?>img/link-to-media-file.png">
                <br /> You can open a single image into SSG too. Use the same option "Link to: Media file", but in the settings of that image.
            </p>

            <p class="text crucial">Write an image caption into an image's
                <strong class="important">Alt text field</strong>. It is in the gallery/image options.
                <a href="https://ssg.flor.cz/wordpress/how-to-easily-caption-multiple-images/" target="_blank">How to easily caption multiple images</a>.<br>
                If you have captions in other field, you can use <a href="https://wordpress.org/plugins/pb-seo-friendly-images/" target="_blank">PB SEO plugin</a> to auto fill alt text fields. It'll help your site rank better in Google.</p>
            </p>

            <form method="post" action="options.php">
<?php			
                    settings_fields ( "ssg_fields" );
                    do_settings_sections ( "story-show-gallery" );
                    submit_button ();
?>
            </form>

            <br>
            <p class="text">
                If you like this plugin, please give it a 
                <a target="_blank" href="https://wordpress.org/support/plugin/story-show-gallery/reviews/?rate=5#new-post">5-star rating »</a>
            </p>

            <h3>Controlling the gallery:</h3>
            <p class="text">
                You can control the gallery by CSS classes. The <strong class="important">nossg</strong> 
                class selectively deactivate SSG for some images or entire gallery.<br />
                The <strong class="important">gossg</strong> class will show image only if a user clicks on it. The <strong class="important">fs</strong> 
                class activates fullscreen mode for single images. <br />
                <img src="<?php echo $ssg_url; ?>img/link-css-class.png">&nbsp;&nbsp;
                <a href="https://ssg.flor.cz/wordpress/controlling-story-show-gallery-by-css-classes/" target="_blank">See short tutorial</a>
            </p>

            <h3>A couple of useful tips:</h3>

            <p class="text">
                Story Show Gallery supports Google Analytics - 
                <a target="_blank" href="https://ssg.flor.cz/wordpress/find-out-how-long-site-visitors-view-each-photo/">
                find out, how long site visitors view each photo</a> <br />
                How to <a target="_blank" href="https://ssg.flor.cz/wordpress/linking-inside-the-story-show-gallery/">
                link directly into Story Show Gallery</a> to show a particular photo.
            </p>
         
        </div>

        <div id="ssg-aside">
            <div class="ssg-box logo">
            <img src="<?php echo $ssg_url; ?>img/ssg-logo.jpg" ></a>
            </div>

            <div class="ssg-box">
                <!-- h3>It's just beginning, more features to come:</h3>
                <ul>
                    <li>Detailed settings</li>
                    <li>A signpost behind the gallery - <a href="https://ssg.flor.cz/signpost/" target="_blank">sample here</a></li>
                    <li>Adding a watermark to images</li>
                    <li>Setting of custom localization</li>
                    <li>Visual and color styles</li>
                </ul -->
                <br><p>
                You can use Story Show Gallery also outside of Wordpress - <a href="https://ssg.flor.cz/" target="_blank">it is easy to implement</a>
                </p>

            </div>
            <div class="ssg-box donate">
                <p>Thank you for using Story Show Gallery. Any size donation is greatly appreciated. It will help me to continue developing this free plugin.</p>
                <a href="https://www.paypal.me/FlorSSG" target="_blank" >
                <img src="<?php echo $ssg_url; ?>img/donate.png" alt="" width="99" height="49"></a>
            </div>
        </div>

        <p class="author"><a href="https://ssg.flor.cz/wordpress/" target="_blank"> Story Show Gallery</a> by Roman Flössler</p> 
<?php
    }

    /* Init setting section, Init setting field and register settings page */
    
    function ssg_settings_form() {
        add_settings_section ( 'ssg_fields', '', null, 'story-show-gallery' );
        add_settings_field ( 'SSG-3danim-checkbox', 'Thumbnails settings:', 'ssg_output_checkbox', 'story-show-gallery', 'ssg_fields' );
        register_setting ( 'ssg_fields', 'SSG-3danim-checkbox' );
    }
    add_action ( 'admin_init', 'ssg_settings_form' );
    
    
    /*  Add checkbox to settings page  */
    
    function ssg_output_checkbox() {
        $checkboxvalue = '';
        if ( 'checked' == get_option( 'SSG-3danim-checkbox' ) ) {
            $checkboxvalue = 'checked';
        } else {
            $checkboxvalue = '';
        }
?>
        <div class="ssg-postbox" >
            <input type="checkbox" name="SSG-3danim-checkbox" value="checked" <?php echo $checkboxvalue; ?> />
             Activate 3D animated thumbnails in the image gallery<br />
        </div>
<?php
    }

    /* Adds SSG script and styles into Wordpress  */
    
    add_action( 'wp_enqueue_scripts', 'ssg_init' );

    function ssg_init() {
        $ssg_url = plugin_dir_url( __FILE__ );
        wp_enqueue_script( 'ssg-js', $ssg_url.'ssg-js/ssg.js', array( 'jquery' ), null, true );        
        if ( 'checked' == get_option( 'SSG-3danim-checkbox' ) ) {
            wp_enqueue_style( 'ssg-combo-style', $ssg_url.'ssg-js/ssg-thumbs.css', array(), null, 'screen' );
        } else {
            wp_enqueue_style( 'ssg-style', $ssg_url.'ssg-js/ssg.css', array(), null, 'screen' );
        }
    }

    /* Admin styles  */

    add_action( 'admin_enqueue_scripts', 'ssg_add_admin_styles' );

    function ssg_add_admin_styles($hook) {
        $current_screen = get_current_screen();
        if ( false === strpos($current_screen->base, 'story-show-gallery') ) {
            return;
        } else {
            wp_enqueue_style( 'ssg_admin_css', plugins_url('css/ssg-admin.css',__FILE__ ) );
        }	
    }

    /* Add settings link to plugin page  */

    add_filter( 'plugin_action_links_'.plugin_basename(__FILE__), 'ssg_add_settings_link' );
    function ssg_add_settings_link( $links ) {
        $links[] = '<a href="' .
            admin_url( 'options-general.php?page=story-show-gallery' ) .
            '">' . __( 'Settings' ) . '</a>';
        return $links;
    }

    /* Set gallery shortcode to link to media file  */

    add_filter( 'shortcode_atts_gallery',
        function( $out ){
            $out['link'] = 'file'; 
            return $out;
        }
    );
?>
